---
title: <span class="badge object-type-enum"></span> SeriesMapping
---
# <span class="badge object-type-enum"></span> SeriesMapping

## Definition

```python
class SeriesMapping(enum.StrEnum):
    AUTO = "auto"
    MANUAL = "manual"
```
